@@ -76,22 +76,14 @@ void SensorFace::setContentItem(QQuickItem *item)
 
     Q_EMIT contentItemChanged();
 }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void SensorFace::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
-#else
 void SensorFace::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
-#endif
 {
     if (d->contentItem) {
         d->contentItem->setX(0);
         d->contentItem->setY(0);
         d->contentItem->setSize(newGeometry.size());
     }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QQuickItem::geometryChanged(newGeometry, oldGeometry);
-#else
     QQuickItem::geometryChange(newGeometry, oldGeometry);
-#endif
 }
 
 #include "moc_SensorFace_p.cpp"
